@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -191,14 +191,7 @@ function zbx_date2str($format, $time = null, string $timezone = null) {
 		return _('Never');
 	}
 
-	if ($time > ZBX_MAX_DATE) {
-		$prefix = '> ';
-		$datetime = new DateTime('@'.ZBX_MAX_DATE);
-	}
-	else {
-		$prefix = '';
-		$datetime = new DateTime('@'.(int) $time);
-	}
+	$datetime = new DateTime(sprintf('@%f', (float) $time));
 
 	$datetime->setTimezone(new DateTimeZone($timezone ?? date_default_timezone_get()));
 
@@ -283,7 +276,7 @@ function zbx_date2str($format, $time = null, string $timezone = null) {
 		}
 	}
 
-	return $prefix.$output;
+	return $output;
 }
 
 /**
@@ -677,9 +670,8 @@ function convertUnits(array $options): string {
  *     'units' =>               (string)    Units to base the conversion on. Default: ''.
  *     'convert' =>             (int)       Default: ITEM_CONVERT_WITH_UNITS. Set to ITEM_CONVERT_NO_UNITS to
  *                                          force-convert a value with empty units.
- *     'power' =>               (int)       Convert to the specified power of "unit_base" (0 => '', 1 => K, 2 => M, ..).
+ *     'power' =>               (int)       Convert to the specified power of units. (0 => '', 1 => K, 2 => M, ...).
  *                                          By default, the power will be calculated automatically.
- *     'unit_base' =>           (string)    1000 or 1024. By default, will only use 1024 for "B" and "Bps" units.
  *     'ignore_milliseconds' => (bool)      Ignore milliseconds in time conversion ("s" units).
  *     'precision' =>           (int)       Max number of significant digits to take into account.
  *                                          Default: ZBX_FLOAT_DIG.
@@ -702,7 +694,6 @@ function convertUnitsRaw(array $options): array {
 		'units' => '',
 		'convert' => ITEM_CONVERT_WITH_UNITS,
 		'power' => null,
-		'unit_base' => null,
 		'ignore_milliseconds' => false,
 		'precision' => ZBX_FLOAT_DIG,
 		'decimals' => null,
@@ -742,11 +733,11 @@ function convertUnitsRaw(array $options): array {
 	if ($units === 's') {
 		if ($options['decimals'] !== null && $options['decimals'] != 0) {
 			return [
-				'value' => convertUnitSWithDecimals($value, $options['ignore_milliseconds'], $options['decimals'],
+				'value' => convertUnitsSWithDecimals($value, $options['ignore_milliseconds'], $options['decimals'],
 					$options['decimals_exact']
 				),
 				'units' => '',
-				'is_mapped' => false
+				'is_numeric' => false
 			];
 		}
 
@@ -783,11 +774,7 @@ function convertUnitsRaw(array $options): array {
 		];
 	}
 
-	$unit_base = $options['unit_base'];
-
-	if ($unit_base != 1000 && $unit_base != ZBX_KIBIBYTE) {
-		$unit_base = isBinaryUnits($units) ? ZBX_KIBIBYTE : 1000;
-	}
+	$unit_base = isBinaryUnits($units) ? ZBX_KIBIBYTE : 1000;
 
 	if ($options['power'] === null) {
 		$result = null;
@@ -1669,7 +1656,7 @@ function access_deny($mode = ACCESS_DENY_OBJECT) {
 	}
 	// deny access to a page
 	else {
-		// url to redirect the user to after he logs in
+		// URL to redirect the user to after logging in.
 		$url = (new CUrl(!empty($_REQUEST['request']) ? $_REQUEST['request'] : ''))->removeArgument(CSRF_TOKEN_NAME);
 
 		if (CAuthenticationHelper::getPublic(CAuthenticationHelper::HTTP_LOGIN_FORM) == ZBX_AUTH_FORM_HTTP
